#include "bar.h"

/*
 *  Constructs a BarDlg as a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
BarDlg::BarDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )

{
    if ( !name )
	setName( "BarDlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 600, 480 ) );
    setMaximumSize( QSize( 600, 480 ) );

    // Sensor Group
    SensorBox = new QGroupBox( this, "SensorBox" );
    SensorBox->setGeometry( QRect( 20, 260, 561, 150 ) );

    useSens = new QCheckBox( SensorBox, "useSens" );
    useSens->setGeometry( QRect( 20, 20, 160, 21 ) );

    SensorCombo = new QComboBox( FALSE, SensorBox, "SensorCombo" );
    SensorCombo->setEnabled( FALSE );
    SensorCombo->setGeometry( QRect( 290, 20, 171, 21 ) );

    Format = new QLineEdit( SensorBox, "Format" );
    Format->setEnabled( FALSE );
    Format->setGeometry( QRect( 110, 50, 160, 21 ) );

    Codec = new QLineEdit( SensorBox, "Codec" );
    Codec->setEnabled( FALSE );
    Codec->setGeometry( QRect( 110, 90, 160, 21 ) );

    Line = new QLineEdit( SensorBox, "Line" );
    Line->setEnabled( FALSE );
    Line->setGeometry( QRect( 390, 90, 160, 21 ) );

    Program = new QLineEdit( SensorBox, "Program" );
    Program->setEnabled( FALSE );
    Program->setGeometry( QRect( 390, 50, 160, 21 ) );
    Program->setReadOnly( FALSE );

    RDF = new QCheckBox( SensorBox, "RDF" );
    RDF->setGeometry( QRect( 20, 120, 160, 21 ) );
    RDF->setEnabled( FALSE );

    LineLabel = new QLabel( SensorBox, "LineLabel" );
    LineLabel->setEnabled( FALSE );
    LineLabel->setGeometry( QRect( 290, 90, 90, 21 ) );
    LineLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    ProgramLabel = new QLabel( SensorBox, "ProgramLabel" );
    ProgramLabel->setEnabled( FALSE );
    ProgramLabel->setGeometry( QRect( 270, 50, 110, 21 ) );
    ProgramLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    FormatLabel = new QLabel( SensorBox, "FormatLabel" );
    FormatLabel->setEnabled( FALSE );
    FormatLabel->setGeometry( QRect( 10, 50, 90, 21 ) );
    FormatLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    CodecLabel = new QLabel( SensorBox, "CodecLabel" );
    CodecLabel->setEnabled( FALSE );
    CodecLabel->setGeometry( QRect( 10, 90, 90, 21 ) );
    CodecLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    SensorLabel = new QLabel( SensorBox, "SensorLabel" );
    SensorLabel->setEnabled( FALSE );
    SensorLabel->setGeometry( QRect( 190, 20, 80, 21 ) );
    SensorLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    // Bar Group
    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 0, 561, 240 ) );
    groupBox1->setFrameShape( QGroupBox::GroupBoxPanel );
    groupBox1->setFrameShadow( QGroupBox::Sunken );

    Pix = new QLineEdit( groupBox1, "Pix" );
    Pix->setGeometry( QRect( 20, 50, 198, 21 ) );

    PixLabel = new QLabel( groupBox1, "PixLabel" );
    PixLabel->setGeometry( QRect( 20, 28, 221, 21 ) );

    pushButton3 = new QPushButton( groupBox1, "pushButton3" );
    pushButton3->setGeometry( QRect( 220, 45, 100, 31 ) );

    Min = new QSpinBox( groupBox1, "Min" );
    Min->setGeometry( QRect( 130, 100, 70, 21 ) );
    Min->setMaxValue( 100 );
    Min->setMinValue( -100 );
    Min->setValue( 0 );

    MinLabel = new QLabel( groupBox1, "MinLabel" );
    MinLabel->setGeometry( QRect( 10, 100, 110, 21 ) );
    MinLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Max = new QSpinBox( groupBox1, "Max" );
    Max->setGeometry( QRect( 130, 130, 70, 21 ) );
    Max->setMaxValue( 100 );
    Max->setMinValue( -100 );
    Max->setValue( 100 );

    MaxLabel = new QLabel( groupBox1, "MaxLabel" );
    MaxLabel->setGeometry( QRect( 10, 130, 110, 21 ) );
    MaxLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Value = new QSpinBox( groupBox1, "Value" );
    Value->setGeometry( QRect( 130, 160, 70, 21 ) );
    Value->setMaxValue( 100 );
    Value->setMinValue( -100 );

    ValueLabel = new QLabel( groupBox1, "ValueLabel" );
    ValueLabel->setGeometry( QRect( 10, 160, 110, 21 ) );
    ValueLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Vertical = new QCheckBox( groupBox1, "Vertical" );
    Vertical->setGeometry( QRect( 20, 200, 85, 20 ) );

    W = new QSpinBox( groupBox1, "W" );
    W->setGeometry( QRect( 450, 130, 70, 21 ) );
    W->setMaxValue( 2048 );

    WidthLabel = new QLabel( groupBox1, "WidthLabel" );
    WidthLabel->setGeometry( QRect( 390, 130, 60, 21 ) );
    WidthLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    H = new QSpinBox( groupBox1, "H" );
    H->setGeometry( QRect( 450, 170, 70, 21 ) );
    H->setMaxValue( 2048 );

    HeightLabel = new QLabel( groupBox1, "HeightLabel" );
    HeightLabel->setGeometry( QRect( 390, 170, 60, 21 ) );
    HeightLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    X = new QSpinBox( groupBox1, "X" );
    X->setGeometry( QRect( 450, 50, 70, 21 ) );
    X->setMaxValue( 2048 );

    XLabel = new QLabel( groupBox1, "XLabel" );
    XLabel->setGeometry( QRect( 400, 50, 40, 21 ) );
    XLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    Y = new QSpinBox( groupBox1, "Y" );
    Y->setGeometry( QRect( 450, 90, 70, 21 ) );
    Y->setMaxValue( 1200 );

    YLabel = new QLabel( groupBox1, "YLabel" );
    YLabel->setGeometry( QRect( 400, 90, 40, 21 ) );
    YLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    // Global
    insCur = new QCheckBox( this, "insCur" );
    insCur->setGeometry( QRect( 20, 420, 300, 20 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 190, 440, 81, 31 ) );
    pushButton1->setIconSet( SmallIconSet( "ok" ));
    pushButton1->setDefault( TRUE );

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 340, 440, 81, 31 ) );
    pushButton2->setIconSet( SmallIconSet( "cancel" ));

    languageChange();
    resize( QSize(600, 480).expandedTo(minimumSizeHint()) );

    // signals and slots connections
    connect( pushButton1, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( pushButton2, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( pushButton3, SIGNAL( clicked() ), this, SLOT( selImage() ) );
    connect( SensorCombo, SIGNAL( activated(const QString&) ), this, SLOT( ChooseProgram() ) );
    connect( useSens, SIGNAL( toggled(bool) ), this, SLOT( UseSensor(bool) ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
BarDlg::~BarDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void BarDlg::languageChange()
{
    // Global
    setCaption( tr2i18n( "Add Bar Meter" ) );
    pushButton1->setText( tr2i18n( "Ok" ) );
    pushButton2->setText( tr2i18n( "Cancel" ) );
    insCur->setText( tr2i18n( "Insert at cursor position" ) );
    // Sensor Group
    SensorBox->setTitle( tr2i18n( "Sensor" ) );
    useSens->setText( tr2i18n( "Use sensor" ) );
    SensorCombo->clear();
    SensorCombo->insertItem( tr2i18n( "CPU" ) );
    SensorCombo->insertItem( tr2i18n( "Memory" ) );
    SensorCombo->insertItem( tr2i18n( "Disk" ) );
    SensorCombo->insertItem( tr2i18n( "Network" ) );
    SensorCombo->insertItem( tr2i18n( "Time" ) );
    SensorCombo->insertItem( tr2i18n( "Uptime" ) );
    SensorCombo->insertItem( tr2i18n( "Sensor" ) );
    SensorCombo->insertItem( tr2i18n( "Textfile" ) );
    SensorCombo->insertItem( tr2i18n( "Noatun" ) );
    SensorCombo->insertItem( tr2i18n( "XMMS" ) );
    SensorCombo->insertItem( tr2i18n( "Program" ) );
    Format->setText( tr2i18n( "%v" ) );
    ProgramLabel->setText( tr2i18n( "Program:" ) );
    FormatLabel->setText( tr2i18n( "Format:" ) );
    SensorLabel->setText( tr2i18n( "Sensor:" ) );
    LineLabel->setText( tr2i18n( "Line:" ) );
    RDF->setText( tr2i18n( "RDF file" ) );
    CodecLabel->setText( tr2i18n( "Encoding:" ) );
    // Bar Group
    groupBox1->setTitle( tr2i18n( "Bar Parameters" ) );
    PixLabel->setText( tr2i18n( "Bar pixmap:" ) );
    pushButton3->setText( tr2i18n( "Browse" ) );
    MaxLabel->setText( tr2i18n( "Max Value:" ) );
    ValueLabel->setText( tr2i18n( "Value:" ) );
    MinLabel->setText( tr2i18n( "Min Value:" ) );
    Vertical->setText( tr2i18n( "Vertical" ) );
    WidthLabel->setText( tr2i18n( "Width:" ) );
    X->setSuffix( tr2i18n( "px" ) );
    HeightLabel->setText( tr2i18n( "Height:" ) );
    H->setSuffix( tr2i18n( "px" ) );
    W->setSuffix( tr2i18n( "px" ) );
    XLabel->setText( tr2i18n( "X axis:" ) );
    Y->setSuffix( tr2i18n( "px" ) );
    YLabel->setText( tr2i18n( "Y axis:" ) );
}

void BarDlg::UseSensor( bool v ){
  SensorLabel->setEnabled(v);
  SensorCombo->setEnabled(v);
  Format->setEnabled(v);
  FormatLabel->setEnabled(v);
  LineLabel->setEnabled(v);
  Line->setEnabled(v);
  ProgramLabel->setEnabled(v);
  Program->setEnabled(v);
  CodecLabel->setEnabled(v);
  Codec->setEnabled(v);
  RDF->setEnabled(v);
  Value->setEnabled(!v);
  ValueLabel->setEnabled(!v);
  if(v){
    ChooseProgram();
  }
}

void BarDlg::ChooseProgram(){
  if(SensorCombo->currentItem() == 0){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%load");
    QToolTip::add( Format, tr2i18n( "%user<br>%system<br>%nice<br>%idle<br>%load (=%v)" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "CPU:" ) );
    Line->setEnabled(true);
    Line->setText("all");
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 1){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%fm");
    QToolTip::add( Format, tr2i18n( "%fm<br>%fmb<br>%um<br>%umb<br>%tm<br>%fs<br>%us<br>%ts" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 2){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "MountPoint:" ) );
    Program->setEnabled(true);
    Program->setText("/");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%f");
    QToolTip::add( Format, tr2i18n( "%f<br>%fp<br>%u<br>%up<br>%t" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 3){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Device:" ) );
    Program->setEnabled(true);
    Program->setText("eth0");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%in");
    QToolTip::add( Format, tr2i18n( "%in<br>%out" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Decimals:" ) );
    Line->setEnabled(true);
    Line->setText("0");
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 4){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("dd.MM.yyyy");
    QToolTip::add( Format, tr2i18n( "d<br>dd<br>ddd<br>dddd<br>M<br>MM<br>MMM<br>MMMM<br>YY<br>YYYY<br>h<br>hh<br>m<br>mm<br>s<br>ss<br>z<br>zzz<br>AP<br>ap" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 5){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%dd %h:%M");
    QToolTip::add( Format, tr2i18n( "%d<br>%h<br>%m<br>%s<br>%H<br>%M<br>%S" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 6){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Type:" ) );
    Program->setEnabled(true);
    Program->setText("temp2");
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 7){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Path:" ) );
    Program->setEnabled(true);
    Program->setText("");
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Line:" ) );
    Line->setEnabled(true);
    Line->setText("");
    RDF->setEnabled(true);
  }
  else if(SensorCombo->currentItem() == 8){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(false);
    Codec->setEnabled(false);
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%id");
    QToolTip::add( Format, tr2i18n( "%id<br>%title<br>%time<br>%remain<br>%length<br>%full" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 9){
    ProgramLabel->setEnabled(false);
    Program->setEnabled(false);
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%title");
    QToolTip::add( Format, tr2i18n( "%title<br>%time<br>%remain<br>%length<br>%full<br>%stitle<br>%artist<br>%album<br>%track<br>%cover<br>%rcover<br>%viewer<br>%rate<br>%freq<br>%channel<br>%monoster<br>%runquit<br>%vol<br>%volup<br>%voldown<br>%prev<br>%play<br>%pause<br>%stop<br>%next<br>%list<br>%ms" ) );
    LineLabel->setEnabled(false);
    Line->setEnabled(false);
    RDF->setEnabled(false);
  }
  else if(SensorCombo->currentItem() == 10){
    ProgramLabel->setEnabled(true);
    ProgramLabel->setText( tr2i18n( "Program:" ) );
    Program->setEnabled(true);
    CodecLabel->setEnabled(true);
    Codec->setEnabled(true);
    Codec->setText((QTextCodec::codecForLocale())->name());
    FormatLabel->setEnabled(true);
    Format->setEnabled(true);
    Format->setText("%v");
    QToolTip::add( Format, tr2i18n( "%v" ) );
    LineLabel->setEnabled(true);
    LineLabel->setText( tr2i18n( "Line:" ) );
    Line->setEnabled(true);
    Line->setText("");
    RDF->setEnabled(false);
  }
}

void BarDlg::selImage(){
    KSimpleConfig conf("karambarc",true);
    conf.setGroup("karamba");
    QString Dir = conf.readEntry("ImageDir", locateLocal("data", "karamba/themes/pics/"));
    QString imgName;
    imgName = KFileDialog::getOpenFileName(Dir, "*.png *.jpg *.jpeg *.xpm", 0, "Open image");
    if( imgName != ""){
      Pix->setText( imgName );
    }
}

#include "bar.moc"
