#include "font.h"

/*
 *  Constructs a Text as a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
FontDlg::FontDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )

{
    if ( !name )
	setName( "FontDlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 600, 210 ) );
    setMaximumSize( QSize( 600, 210 ) );

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 0, 561, 140 ) );
    groupBox1->setFrameShape( QGroupBox::GroupBoxPanel );
    groupBox1->setFrameShadow( QGroupBox::Sunken );

    comboBox3 = new KFontCombo( groupBox1, "comboBox3" );
    comboBox3->setGeometry( QRect( 70, 30, 151, 21 ) );

    textLabel2_4 = new QLabel( groupBox1, "textLabel2_4" );
    textLabel2_4->setGeometry( QRect( 10, 30, 50, 21 ) );
    textLabel2_4->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    spinBox5 = new QSpinBox( groupBox1, "spinBox5" );
    spinBox5->setGeometry( QRect( 340, 30, 55, 21 ) );
    spinBox5->setValue(10);

    textLabel3_2 = new QLabel( groupBox1, "textLabel3_2" );
    textLabel3_2->setGeometry( QRect( 240, 30, 90, 21 ) );
    textLabel3_2->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    pushButton3 = new QPushButton( groupBox1, "pushButton3" );
    pushButton3->setGeometry( QRect( 430, 20, 121, 31 ) );
    pushButton3->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );

    spinBox6 = new QSpinBox( groupBox1, "spinBox6" );
    spinBox6->setGeometry( QRect( 340, 70, 55, 20 ) );
    spinBox6->setMinValue( -99 );

    textLabel4_2 = new QLabel( groupBox1, "textLabel4_2" );
    textLabel4_2->setGeometry( QRect( 240, 70, 91, 21 ) );
    textLabel4_2->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    pushButton4 = new QPushButton( groupBox1, "pushButton4" );
    pushButton4->setGeometry( QRect( 430, 60, 121, 31 ) );
    pushButton4->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    pushButton4->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );

    textLabel1_4 = new QLabel( groupBox1, "textLabel1_4" );
    textLabel1_4->setGeometry( QRect( 50, 70, 50, 21 ) );
    textLabel1_4->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    comboBox2 = new QComboBox( FALSE, groupBox1, "comboBox2" );
    comboBox2->setGeometry( QRect( 110, 70, 111, 21 ) );

    checkBox2 = new QCheckBox( groupBox1, "checkBox2" );
    checkBox2->setGeometry( QRect( 30, 110, 85, 20 ) );

    insCur = new QCheckBox( this, "insCur" );
    insCur->setGeometry( QRect( 20, 145, 300, 20 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 190, 170, 81, 31 ) );
    pushButton1->setIconSet( SmallIconSet( "ok" ));
    pushButton1->setDefault( TRUE );

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 340, 170, 81, 31 ) );
    pushButton2->setIconSet( SmallIconSet( "cancel" ));

    languageChange();

    // signals and slots connections
    connect( pushButton1, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( pushButton2, SIGNAL( clicked() ), this, SLOT( close() ) );
    connect( pushButton3, SIGNAL( clicked() ), this, SLOT( selColor() ) );
    connect( pushButton4, SIGNAL( clicked() ), this, SLOT( selShadow() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
FontDlg::~FontDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void FontDlg::languageChange()
{
    setCaption( tr2i18n( "Add Default Font" ) );
    pushButton2->setText( tr2i18n( "Cancel" ) );
    pushButton1->setText( tr2i18n( "Ok" ) );
    groupBox1->setTitle( tr2i18n( "Font Parameters" ) );
    textLabel2_4->setText( tr2i18n( "Font:" ) );
    textLabel3_2->setText( tr2i18n( "Font Size:" ) );
    pushButton3->setText( tr2i18n( "Font Color" ) );
    textLabel4_2->setText( tr2i18n( "Shadow" ) );
    pushButton4->setText( tr2i18n( "Shadow Color" ) );
    textLabel1_4->setText( tr2i18n( "Align:" ) );
    comboBox2->clear();
    comboBox2->insertItem( tr2i18n( "Left" ) );
    comboBox2->insertItem( tr2i18n( "Center" ) );
    comboBox2->insertItem( tr2i18n( "Right" ) );
    checkBox2->setText( tr2i18n( "Fixedpitch" ) );
    insCur->setText( tr2i18n( "Insert at cursor position" ) );
}

void FontDlg::selColor(){
  //QColor myColor;
  int result = KColorDialog::getColor( textColor );
   if ( result == KColorDialog::Accepted ){
      pushButton3->setPaletteBackgroundColor( textColor );
   }
}

void FontDlg::selShadow(){
  //QColor myColor;
  int result = KColorDialog::getColor( shadow );
   if ( result == KColorDialog::Accepted ){
      pushButton4->setPaletteBackgroundColor( shadow );
   }
}

#include "font.moc"
