#include "group.h"

/*
 *  Constructs a GroupDlg as a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
GroupDlg::GroupDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )

{
    if ( !name )
	setName( "GroupDlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 400, 130 ) );
    setMaximumSize( QSize( 400, 130 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 80, 90, 81, 31 ) );
    pushButton1->setIconSet( SmallIconSet( "ok" ));
    pushButton1->setDefault( TRUE );

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 230, 90, 81, 31 ) );
    pushButton2->setIconSet( SmallIconSet( "cancel" ));

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setGeometry( QRect( 20, 0, 360, 80 ) );
    groupBox1->setFrameShape( QGroupBox::GroupBoxPanel );
    groupBox1->setFrameShadow( QGroupBox::Sunken );

    spinBox1 = new QSpinBox( groupBox1, "spinBox1" );
    spinBox1->setGeometry( QRect( 70, 30, 70, 21 ) );
    spinBox1->setMaxValue( 2048 );

    textLabel1 = new QLabel( groupBox1, "textLabel1" );
    textLabel1->setGeometry( QRect( 30, 30, 40, 21 ) );
    textLabel1->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );

    spinBox2 = new QSpinBox( groupBox1, "spinBox2" );
    spinBox2->setGeometry( QRect( 240, 30, 70, 21 ) );
    spinBox2->setMaxValue( 1200 );

    textLabel2 = new QLabel( groupBox1, "textLabel2" );
    textLabel2->setGeometry( QRect( 200, 30, 40, 21 ) );
    textLabel2->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignRight ) );
    languageChange();
    resize( QSize(400, 130).expandedTo(minimumSizeHint()) );

    // signals and slots connections
    connect( pushButton1, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( pushButton2, SIGNAL( clicked() ), this, SLOT( close() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
GroupDlg::~GroupDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void GroupDlg::languageChange()
{
    setCaption( tr2i18n( "Add Group" ) );
    pushButton1->setText( tr2i18n( "Ok" ) );
    pushButton2->setText( tr2i18n( "Cancel" ) );
    groupBox1->setTitle( tr2i18n( "Group Parameters" ) );
    spinBox1->setPrefix( QString::null );
    spinBox1->setSuffix( tr2i18n( "px" ) );
    textLabel1->setText( tr2i18n( "X axis:" ) );
    spinBox2->setPrefix( QString::null );
    spinBox2->setSuffix( tr2i18n( "px" ) );
    textLabel2->setText( tr2i18n( "Y axis:" ) );
}

void GroupDlg::ChooseProgram()
{
    qWarning( "GroupDlg::ChooseProgram(): Not implemented yet" );
}

#include "group.moc"
