/***************************************************************************
 *   Copyright (C) 2003 by Hans Karlsson                                   *
 *   karlsson.h@home.se                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "imagelabel.h"
#include <qtimer.h>
#include <qtooltip.h>

ImageLabel::ImageLabel(int ix,int iy,int iw,int ih)
 : Meter(ix,iy,iw,ih), zoomed(false), rollover(false)
 {

}

ImageLabel::ImageLabel() : Meter(), zoomed(false), rollover(false){


}
ImageLabel::~ImageLabel(){


}

void ImageLabel::setValue(int v){
 setValue( QString::number( v ) );
}

void ImageLabel::setValue(QString fn)
{
  // use the first line
  QStringList sList = QStringList::split( "\n", fn );
  QString fileName = *sList.begin();
  QFileInfo fileInfo( fileName );
  QString path;

  QRegExp rx("^http://",false);
  bool fileOnNet = (rx.search(fileName)!=-1)?true:false;


  if( fileInfo.isRelative() && !fileOnNet )
  {
     path = themePath + "/" + fileName;
  }
  else
  {
     path = fileName;
  }

  if ( fileOnNet )
  {
      QString tmpFile;
      if(KIO::NetAccess::download(KURL(path), tmpFile))
      {
          pixmap = QPixmap(tmpFile);
          KIO::NetAccess::removeTempFile(tmpFile);
           qDebug( "Downloaded: " + path + " to " + tmpFile );
      }
      else
      {
          qDebug( "Error Downloading: " + path );
      }
  }
  else
  {
    pixmap = QPixmap( path );
  }

  pixmapWidth = pixmap.width();
  pixmapHeight = pixmap.height();

  rect_off = QRect(x,y,pixmapWidth,pixmapHeight);
}

void ImageLabel::setCenter(bool c, int w, int h){
  if(h == 0 || w == 0){
    width = QApplication::desktop()->width();
    height = QApplication::desktop()->height();
  }
  else{
    width = w + 2*x;
    height = h + 2*y;
  }
  center = c;
}

void ImageLabel::mUpdate(QPainter* p)
{
  if(center == true){
    x = width/2 - pixmap.width()/2;
    y = height/2 - pixmap.height()/2;
  }
  if( ( (myKaramba->x() + myKaramba->themeW) >= 0) && ( (myKaramba->x() + x) <= QApplication::desktop()->width()) && ( (myKaramba->y() + myKaramba->themeH) >= 0) && ( (myKaramba->y() + y) <= QApplication::desktop()->height()) ){
    p->drawPixmap(x,y,pixmap);
  }
}

void ImageLabel::parseImages(QString fn, QString fn_roll, int _xoff, int _yoff, int _xon, int _yon)
{
	//fn = filename;
	//fn_roll = filename_roll;

	xoff = _xoff;
	yoff = _yoff;
	xon = _xon;
	yon = _yon;

	// use the first line
	QStringList sList = QStringList::split( "\n", fn );
	QString fileName = *sList.begin();
	QFileInfo fileInfo( fileName );
	QString path;

	QRegExp rx("^http://",false);
	bool fileOnNet = (rx.search(fileName)!=-1)?true:false;


	if( fileInfo.isRelative() && !fileOnNet )
	{
	 path = themePath + "/" + fileName;
	}
	else
	{
	 path = fileName;
	}

	if ( fileOnNet )
	{
	  QString tmpFile;
	  if(KIO::NetAccess::download(KURL(path), tmpFile))
	  {
		  pixmap_off = QPixmap(tmpFile);
		  KIO::NetAccess::removeTempFile(tmpFile);
		   qDebug( "Downloaded: " + path + " to " + tmpFile );
	  }
	  else
	  {
		  qDebug( "Error Downloading: " + path );
	  }
	}
	else
	{
		pixmap_off = QPixmap( path );
	}

	pixmapOffWidth = pixmap.width();
	pixmapOffHeight = pixmap.height();

	rect_off = QRect(xoff,yoff,pixmapWidth,pixmapHeight);
/////////////////////////////
	if (fn_roll.isEmpty())
		return;

	rollover=true;
	sList = QStringList::split( "\n", fn_roll );
	fileName = *sList.begin();
	fileInfo = QFileInfo( fileName );

	fileOnNet = (rx.search(fileName)!=-1)?true:false;


	if( fileInfo.isRelative() && !fileOnNet )
	{
	 path = themePath + "/" + fileName;
	}
	else
	{
	 path = fileName;
	}

	if ( fileOnNet )
	{
	  QString tmpFile;
	  if(KIO::NetAccess::download(KURL(path), tmpFile))
	  {
		  pixmap_on = QPixmap(tmpFile);
		  KIO::NetAccess::removeTempFile(tmpFile);
		   qDebug( "Downloaded: " + path + " to " + tmpFile );
	  }
	  else
	  {
		  qDebug( "Error Downloading: " + path );
	  }
	}
	else
	{
		pixmap_on = QPixmap( path );
	}

	pixmapOnWidth = pixmap_on.width();
	pixmapOnHeight = pixmap_on.height();

	rect_on = QRect(xon,yon,pixmapOnWidth,pixmapOnHeight);
}

void ImageLabel::setKaramba(karamba* k)
{
	myKaramba = k;
}

void ImageLabel::rolloverImage(QMouseEvent *e)
{
	if (!rollover)
		return;
	
	if (zoomed)
	{
		if (!rect_off.contains(e->pos()))
		{
			// rollover the image to the zoomed image
			//setValue(fn_roll);
			x = xoff;
			y = yoff;
			pixmap = pixmap_off;
			pixmapWidth = pixmapOffWidth;
			pixmapHeight = pixmapOffHeight;
			zoomed = false;
			myKaramba->step();
		}
	}
	else
	{
		if (rect_off.contains(e->pos()))
		{
			// rollover the image to the zoomed image
			//setValue(fn_roll);
			x = xon;
			y = yon;
			pixmap = pixmap_on;
			pixmapWidth = pixmapOnWidth;
			pixmapHeight = pixmapOnHeight;
			zoomed = true;
			myKaramba->step();
		}
	}
}

void ImageLabel::setTooltip(QString txt)
{
	QRect rect(x,y,pixmapWidth,pixmapHeight);
	QToolTip::add(myKaramba, rect, txt);
}
