/***************************************************************************
*   Copyright (C) 2003 by Hans Karlsson                                   *
*   karlsson.h@home.se                                                      *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/
#include "xmmssensor.h"

XMMSSensor::XMMSSensor( int interval, QString encoding, int nw, int nh, karamba* k ) : Sensor( interval )
{
     if( encoding != "" )
    {
        codec = QTextCodec::codecForName( encoding );
        if ( codec == 0)
            codec = QTextCodec::codecForLocale();
    }
    else{
        codec = QTextCodec::codecForLocale();
    }
    w = getW( nw );
    h = getH( nh );
    current = 0;
    pos = 0;
    title = "";
    stitle = "";
    artist = "";
    album = "";
    track = "";
    vol = 0;
    refresh = true;
    setKaramba(k);
}
XMMSSensor::~XMMSSensor()
{}

int XMMSSensor::getW( int nw ){
  if(nw == 0){
  KSimpleConfig conf("karambarc",true);
  conf.setGroup("XMMS");
  w = conf.readNumEntry("CoverWidth",64);
  }
  else{
    w = nw;
  }
   return w;
}

int XMMSSensor::getH( int nh ){
  if(nh == 0){
  KSimpleConfig conf("karambarc",true);
  conf.setGroup("XMMS");
  h = conf.readNumEntry("CoverHeight",64);
  }
  else{
    h = nh;
  }
  return h;
}

QString XMMSSensor::setCover(){
  fp = locateLocal("tmp", "cover.png");
  QImage img;
  QImage tmpimg;
  img.load(rcover);
  if(img.width() >= w || img.height() >= h){ //scale image if necessary
    tmpimg = img.smoothScale(h, w, QImage::ScaleMin);
    tmpimg.save(fp, "PNG", 0);
  }
  else{
    fp = rcover;
  }
  return fp;
}

bool XMMSSensor::id3cover(QString file){
  myTag = new ID3_Tag();
  myTag->Link(file, ID3TT_ALL);
  ID3_Frame* myFrame = myTag->Find(ID3FID_PICTURE);// Check if id3 have PICTURE field
  if (NULL != myFrame){
    //qDebug("id3 have picture ");
    fp = locateLocal("tmp", "cover.png");
    ID3_Field* myField = myFrame->GetField(ID3FN_DATA);
     const uchar* data = myField->GetRawBinary();
     size_t size = myField->Size();
    QImage img;
    QImage tmpimg;
    img.loadFromData (data, size);
    if(img.width() >= w || img.height() >= h){ //scale image if necessary
      tmpimg = img.scale(h, w, QImage::ScaleMin);
    }
    tmpimg.save(fp, "PNG", 0);
    img.save( locateLocal("tmp", "rcover.png"), "PNG", 0);
    return true;
  }
  else{
    //qDebug("id3 don't have picture");
    return false;
  }
}

bool XMMSSensor::darkcover(){
  QString ar = (artist.lower()).replace(" ", "_");
  QString al = (album.lower()).replace(" ", "_");
  QString l = ar.left(1);
  QString out = dir+"/cover.jpg";
  QString mime = "";
  KURL u1("http://img.darktown.com/cover/audio/download/"+l+"/"+ar+"-_"+al+"a.jpg");
  mime = KIO::NetAccess::mimetype( u1 );
  if( mime == "image/jpeg" )
  {
    return KIO::NetAccess::download( u1, out );
  }
  else{
    //qDebug(u1.url());
    KURL u2("http://img.darktown.com/cover/audio/download/"+l+"/"+ar+al+"a.jpg");
    mime = KIO::NetAccess::mimetype( u2 );
    if( mime == "image/jpeg" )
    {
      return KIO::NetAccess::download( u2, out );
    }
    else{
      //qDebug(u2.url());
      QString ar = (upFirst(artist.lower())).replace(" ", "_");
      QString al = (upFirst(album.lower())).replace(" ", "_");
      KURL u3("http://img.darktown.com/cover/audio/download/"+l+"/"+ar+al+"a.jpg");
      mime = KIO::NetAccess::mimetype( u3 );
      if( mime == "image/jpeg" )
      {
        return KIO::NetAccess::download( u3, out );
      }
      else{
        //qDebug(u3.url());
        return false;
      }
    }
  }
}

void XMMSSensor::update(){
    QString format;
    QString imgsize;
    SensorParams *sp;
    Meter *meter;
    QObjectListIt it( *objList );
#ifdef HAVE_XMMS
    int currentTime = 0;
    bool isPlaying = false;
    bool isRunning = xmms_remote_is_running(0);
    bool id3c = false;
    KSimpleConfig conf("karambarc",true);
    conf.setGroup("karamba");
    QString Viewer =  conf.readEntry("ImgViewer", "kuickshow");
    conf.setGroup("XMMS");
    bool EnableID3 = conf.readBoolEntry("EnableId3",false);
    bool SaveID3 = conf.readBoolEntry("SaveId3",false);
    bool EnableCover = conf.readBoolEntry("EnableCover",false);
    bool EnableID3C = conf.readBoolEntry("EnableId3Cover",false);
    bool NetCover = conf.readBoolEntry("EnableNetCover",false);
    bool HideMainWin = conf.readBoolEntry("HideMainWin",false);
    if( isRunning ){
        if( xmms_remote_is_main_win(0) == true && HideMainWin == true){
          xmms_remote_main_win_toggle(0, false);
        }
        isPlaying = xmms_remote_is_playing(0);
        pos = xmms_remote_get_playlist_pos(0);
        currentTime = xmms_remote_get_output_time( 0 );
        if(pos != current){
          current = pos;
          freq = 0;
          channel = 0;
          rate = 0;
          qDebug("Song change, updating values");
          title = "";
          stitle = "";
          artist = "";
          album = "";
          track = "";
          cover = "";
          rcover = "";
          file = codec->toUnicode( QCString( xmms_remote_get_playlist_file( 0, pos ) ) ); //get the path and filename
          if((file.section('.', -1) == "mp3" || file.section('.', -1) == "MP3") && EnableID3 == true){ // Check if file is an mp3
            myTag = new ID3_Tag();
            myTag->Link(file, ID3TT_ALL);
            const Mp3_Headerinfo * mp3header = myTag->GetMp3HeaderInfo();
            rate = mp3header->bitrate;
            int chmode = mp3header->channelmode;
            if(chmode == 0 || chmode == 1 || chmode == 2){
              channel = 2;
            }
            else if(chmode == 3 || chmode == 4){
              channel = 1;
            }
            else{
              channel = 0;
            }
            int tmpfreq = mp3header->frequency;
            freq = ((QString::number(tmpfreq).toDouble())/1000);
            qDebug("Getting tags from MP3 file");
            stitle = upFirst(ID3_GetTitle(myTag));
            artist = upFirst(ID3_GetArtist(myTag));
            album = upFirst(ID3_GetAlbum(myTag));
            track = ID3_GetTrack(myTag);
            if(stitle != ""){
              title = artist + " - " + stitle + " - " + album;
            }
          }
          else if((file.section('.', -1) == "ogg" || file.section('.', -1) == "OGG") && EnableID3 == true){ // Check if file is an ogg
            OggVorbis_File  o;
            FILE *f = fopen( file, "rb");
            int t = ov_open(f, &o, NULL, 0);
            if(t == 0){
              // this part comes from KTagit http://ktagit.sourceforge.net/
              char **ptr = ov_comment(&o, -1)->user_comments;
              qDebug("Getting tags from OGG file");
              for(; *ptr; ptr++){
                  QString tmp(QString::fromUtf8(*ptr));
                  if(tmp.find('='))
                  {
                  QString tag (tmp.section('=', 0, 0).lower());
                  QString value (tmp.section('=', 1, 1));
                  if(!tag.compare("title"))
                    stitle = upFirst(value);
                  if(!tag.compare("artist"))
                    artist = upFirst(value);
                  if(!tag.compare("album"))
                    album = upFirst(value);
                  if(!tag.compare("track"))
                    track = value;
                 }
              }
              //---//
              if(stitle != ""){
                title = artist + " - " + stitle + " - " + album;
                int tmpfreq;
                xmms_remote_get_info(0, &rate, &tmpfreq, &channel);
                freq = ((QString::number(tmpfreq).toDouble())/1000);
                rate = ov_bitrate(&o, -1);
              }
            }
            else{
              qDebug("err: " + QString::number(t));
              fclose(f);
           }
             ov_clear(&o);
          }
          if( title == "" ){
            qDebug("Getting tags from XMMS");
            title = codec->toUnicode( QCString( xmms_remote_get_playlist_title( 0, pos ) ) );
            title = upFirst(title);
            if(title.contains(" - ")){
            /**
            * this works only if you set
            * XMMS to display song informations like this:
            * %n - %p - %t - %a
            * this is an automatic detection, so the values may be incorrect.
            */
              track = (title.section("- ", 0, 0)).stripWhiteSpace();
              artist = (title.section("- ", 1, 1)).stripWhiteSpace();
              stitle = (title.section("- ", 2, 2)).stripWhiteSpace();
              album = (title.section("- ", 3, 3)).stripWhiteSpace();
              if((file.section('.', -1) == "mp3" || file.section('.', -1) == "MP3") && SaveID3 == true){ // Check if file is an mp3
                qDebug("Adding id3 tags to file " + file);
                myTag = new ID3_Tag();
                myTag->Link(file, ID3TT_ALL);
                ID3_AddTitle(myTag, stitle, true);
                ID3_AddAlbum(myTag, album, true);
                ID3_AddArtist(myTag, artist, true);
                ID3_AddTrack(myTag, track.latin1() , '0', true);
                myTag->Update();
                myTag = 0;
              }
            }
            int tmpfreq;
            xmms_remote_get_info(0, &rate, &tmpfreq, &channel);
            freq = ((QString::number(tmpfreq).toDouble())/1000);
          }
          qDebug(title);
          if(channel == 1){
            monoster = "mono";
          }
          else if(channel == 2){
            monoster = "stereo";
          }
          else{
            monoster = "nosound";
          }
          songLength = xmms_remote_get_playlist_time( 0, pos );
          if(EnableCover){
            id3c = false;
            if((file.section('.', -1) == "mp3" || file.section('.', -1) == "MP3") && EnableID3C == true){ // Check if file is an mp3
              id3c = id3cover(file);
              if(id3c){
                cover = locateLocal("tmp", "cover.png");
                rcover = locateLocal("tmp", "rcover.png");
              }
            }
            if(!id3c){ // File is not an mp3 or don't have id3 PICTURE field
              QUrl url(file); //make QUrl from QString
              dir = url.dirPath (); //resolve the absolute path
              if(QFile::exists(dir + "/cover.png")){
                rcover = dir + "/cover.png";
                cover = setCover();
              }
              else if(QFile::exists(dir + "/cover.jpg")){
                rcover = dir + "/cover.jpg";
                cover = setCover();
              }
              else if(QFile::exists(dir + "/cover.jpeg")){
                rcover = dir + "/cover.jpeg";
                cover = setCover();
              }
              else if(NetCover && QFileInfo(dir).isWritable()){ //check if config allow cover download and if dir is writable
                if(darkcover()){
                  rcover = dir + "/cover.jpg";
                  cover = setCover();
                }
              }
              if(cover == ""){
                rcover = "pics/nocover.png";
                cover = "pics/nocover.png";
              }
            }
          }
        }
    }
#endif // HAVE_XMMS
      while (it != 0)
      {
          sp = (SensorParams*)(*it);
          meter = sp->getMeter();
  #ifdef HAVE_XMMS
          if( isRunning ){
              format = sp->getParam("FORMAT");
              if (format.length() == 0 ){
                  format = "%title %time / %length";
              }
              if( format == "%ms" ){
                  meter->setMax( songLength );
                  meter->setValue( currentTime );
              }
              else{
                  if ( format == "%full" ){
                      meter->setValue( 1 );
                  }
                  else{
                    if(format.contains("%title")){
                      format.replace( "%title", title );
                    }
                    if(EnableCover == true && format.contains("%cover")){
                      format.replace( "%cover", cover );
                    }
                    if(EnableCover == true && format.contains("%viewer")){
                      format.replace( "%viewer", Viewer );
                    }
                    if(EnableCover == true && format.contains("%rcover")){
                      format.replace( "%rcover", rcover );
                    }
                    if(format.contains("%stitle")){
                      format.replace( "%stitle", stitle );
                    }
                    if(format.contains("%artist")){
                      format.replace( "%artist", artist );
                    }
                    if(format.contains("%album")){
                      format.replace( "%album", album );
                    }
                    if(format.contains("%track")){
                      format.replace( "%track", track );
                    }
                    if(format.contains("%rate")){
                      format.replace( "%rate", QString::number(rate/1000) );
                    }
                    if(format.contains("%freq")){
                      format.replace( "%freq", QString::number(freq) );
                    }
                    if(format.contains("%channel")){
                    format.replace( "%channel", QString::number(channel) );
                    }
                    if(format.contains("%monoster")){
                    format.replace( "%monoster", monoster );
                    }
                    if( format.contains("%runquit") ){
                      format.replace("%runquit", "exit");
                    }
                    if(format == "%onoff"){
                      format.replace( "%onoff", "xmms-shell -e xmmsexit" );
                    }
                    if(format == "%play"){
                      format.replace( "%play", "xmms-shell -e play" );
                    }
                    if(format == "%pause"){
                      format.replace( "%pause", "xmms-shell -e pause" );
                    }
                    if(format == "%stop"){
                      format.replace( "%stop", "xmms-shell -e stop" );
                    }
                    if(format == "%next"){
                      format.replace( "%next", "xmms-shell -e next" );
                    }
                    if(format == "%prev"){
                      format.replace( "%prev", "xmms-shell -e previous" );
                    }
                    if(format == "%volup"){
                      format.replace( "%volup", "xmms-shell -e +" );
                    }
                    if(format == "%voldown"){
                      format.replace( "%voldown", "xmms-shell -e -" );
                    }
                    if(format.contains("%vol")){
                      vol = xmms_remote_get_main_volume( 0 );
                      format.replace( "%vol", QString::number(vol) );
                    }
                    if(format.contains("%list")){
                      if(xmms_remote_is_pl_win(0) == true){
                        format.replace( "%list", "xmms-shell -e 'window playlist hide'" );
                      }
                      else{
                        format.replace( "%list", "xmms-shell -e 'window playlist show'" );
                      }
                    }
                    if(format.contains("%length")){
                      format.replace( "%length", QTime( 0,0,0 ).addMSecs( songLength ).toString( "h:mm:ss" ) );
                    }
                    if(format.contains("%time")){
                      format.replace( "%time", QTime( 0,0,0 ).addMSecs( currentTime ).toString( "h:mm:ss" ) );
                    }
                    if(isPlaying && format.contains("%remain")){
                        format.replace( "%remain", QTime( 0,0,0 ).addMSecs( songLength ).addMSecs(-currentTime ).toString( "h:mm:ss" ) );
                    }
                    else if(format.contains("%remain")){
                        format.replace( "%remain", QTime( 0,0,0 ).toString("h:mm:ss" ) );
                    }
                    meter->setValue(format);
                  }
              }
         }
          else{
              format = sp->getParam("FORMAT");
              if(format == "%onoff"){
                format.replace( "%onoff", "xmms" );
                meter->setValue(format);
              }
              else if(format == "%title"){
                format.replace( "%title", "Karamba XMMS Sensor" );
                meter->setValue(format);
              }
              else if(format == "%cover" && EnableCover == true){
                format.replace( "%cover", "pics/nocover.png" );
                meter->setValue(format);
              }
              else if( format.contains("%runquit") ){
                format.replace("%runquit", "launch");
                meter->setValue(format);
              }
              else{
                meter->setValue("");
              }
          }
  #endif // HAVE_XMMS
          ++it;
      }
  }

void XMMSSensor::setMaxValue( SensorParams *sp){
    Meter *meter;
    meter = sp->getMeter();
    QString f;
    f = sp->getParam("FORMAT");

    if ( f == "%full" )
        meter->setMax( 1 );
}

QString XMMSSensor::upFirst( QString str){
  QStringList ls = 0;
  QString upstr = 0;
  ls = QStringList::split( ' ', str);
  QStringList::Iterator it = ls.begin();
  while( it!= ls.end() ){
    QString word = *it;
    QChar i = word.at(0);
    word.replace ( 0, 1, i.upper() );
    upstr += word + " " ;
    ++it;
  }
  if(upstr.right(3) == " - "){
    upstr = upstr.remove(upstr.length() - 3, 3);
  }
  return upstr;
}

void XMMSSensor::setKaramba(karamba* k)
{
	myKaramba = k;
}
