/***************************************************************************
 *   Copyright (C) 2003 by Hans Karlsson                                   *
 *   karlsson.h@home.se                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef XMMSSENSOR_H
#define XMMSSENSOR_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_XMMS
#include <xmmsctrl.h>
#endif // HAVE_XMMS
#include <id3/tag.h>
#include <id3/misc_support.h>
#include <vorbis/vorbisfile.h>
#include <vorbis/codec.h>

#include <stdlib.h>
#include <stdio.h>
#include <qdatetime.h>
#include <qregexp.h>
#include <qtextcodec.h>
#include <qtooltip.h>
#include <qurl.h>
#include <qfile.h>
#include <qimage.h>

#include <ksimpleconfig.h>
#include <kstandarddirs.h>
#include <kio/netaccess.h>
#include <kio/jobclasses.h>

#include "sensor.h"
#include "clickarea.h"

/**
 * @author Hans Karlsson <karlsson.h@home.se>
 * @version 0.17
 */

class XMMSSensor :  public Sensor
{
    Q_OBJECT
public:
    /**
    * create a new XMMS sensor with refresh interval "interval" and character encoding "encoding"
    */
    XMMSSensor( int interval, QString encoding="", int nw = 0, int nh = 0, karamba* k = 0 );
    /**
    * destructor
    */
    ~XMMSSensor();
    /**
    * update sensor display
    */
    void update();
    /**
    * set sensor max values
    */
    void setMaxValue( SensorParams *);
    /**
    * get cover width from karambarc
    */
    int getW( int nw = 0 );
    /**
    * get cover height from karambarc
    */
    int getH(int nh = 0 );
    /**
    * get cover from file location
    */
    QString setCover();
    /**
    * get cover from id3 tag
    */
    bool id3cover(QString file);
    /**
    * pass Karamba pointer to sensor
    */
    void setKaramba(karamba*);
    /**
    * get cover from Darktown
    */
    bool darkcover();

private:
   /**
    * Case upper the first letter of each words
    */
    QString upFirst(QString str);
    /**
    * text encoding
    */
    QTextCodec *codec;
    /**
    * cover thumbnail width
    */
    int w;
    /**
    * cover thumbnail height
    */
    int h;
    /**
    * volume
    */
    int vol;
    /**
    * music file path
    */
    QString dir;
     /**
    * cover thumbnail path
    */
   QString cover;
    /**
    * real cover path
    */
    QString rcover;
    /**
    * file pointer on temporary cover file
    */
    QString fp;
    /**
    * song title
    */
    QString title;
    /**
    * artist
    */
    QString artist;
    /**
    * album
    */
    QString album;
    /**
    * song title
    */
    QString stitle;
    /**
    * track number
    */
    QString track;
    /**
    * last position in playlist
    */
    int current;
    /**
    * music file
    */
    QString file;
    /**
    * bitrate in bps
    */
    int rate;
    /**
    * frequency in hz
    */
    double freq;
    /**
    * number of channel (1 = mono, 2 = stereo)
    */
    int channel;
    /**
    * QString "mono" or "stereo"
    */
    QString monoster;
    /**
    * position in playlist
    */
    int pos;
    /**
    * song length
    */
    int songLength;
    /**
    * pointer on id3 tag
    */
    ID3_Tag* myTag;
    /**
    * pointer on Karamba instance
    */
    karamba* myKaramba;
    /**
    * read sensor params
    */
    bool refresh;


};


#endif // XMMSSENSOR_H
